==> ncursesw-0.6.0.crate: ncursesw-0.6.0/src/size.rs <==
/*
    src/size.rs

    Copyright (c) 2019 Stephen Whittle  All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"),
    to deal in the Software without restriction, including without limitation
    the rights to use, copy, modify, merge, publish, distribute, sublicense,
    and/or sell copies of the Software, and to permit persons to whom
    the Software is furnished to do so, subject to the following conditions:
    The above copyright notice and this permission notice shall be included
    in all copies or substantial portions of the Software.
    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
    THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
    IN THE SOFTWARE.
*/

use std::fmt::{Display, Formatter, Result};

/// A size (usually a window).
#[derive(Copy, Clone, Debug, PartialEq, Eq, Hash)]
pub struct Size {
    /// The number of lines (y-axis)
    pub lines:   i32,
    /// The number of columns (x-axis)
    pub columns: i32
}

/// Default size of 0 lines and 0 columns.
impl Default for Size {
    fn default() -> Self {
        Self { lines: 0, columns: 0 }
    }
}

impl Display for Size {
    fn fmt(&self, f: &mut Formatter) -> Result {
        write!(f, "(lines: {}, columns: {})", self.lines, self.columns)
    }
}

==> ncursesw-0.6.4.crate: ncursesw-0.6.4/src/size.rs <==
/*
    src/size.rs

    Copyright (c) 2019-2022 Stephen Whittle  All rights reserved.

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"),
    to deal in the Software without restriction, including without limitation
    the rights to use, copy, modify, merge, publish, distribute, sublicense,
    and/or sell copies of the Software, and to permit persons to whom
    the Software is furnished to do so, subject to the following conditions:
    The above copyright notice and this permission notice shall be included
    in all copies or substantial portions of the Software.
    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
    THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
    IN THE SOFTWARE.
*/

use std::fmt::{Display, Formatter, Result};

/// A size (usually a window).
#[derive(Copy, Clone, Debug, PartialEq, Eq, PartialOrd, Ord, Hash)]
pub struct Size {
    /// The number of lines (y-axis)
    pub lines:   i32,
    /// The number of columns (x-axis)
    pub columns: i32
}

/// Default size of 0 lines and 0 columns.
impl Default for Size {
    fn default() -> Self {
        Self { lines: 0, columns: 0 }
    }
}

impl Display for Size {
    fn fmt(&self, f: &mut Formatter) -> Result {
        write!(f, "(lines: {}, columns: {})", self.lines, self.columns)
    }
}
